@@ -9,10 +9,10 @@ from pathlib import Path
 
 import securesystemslib
 import tuf.roledb
-from securesystemslib.exceptions import Error as SSLibError, RepositoryError
+from securesystemslib.exceptions import Error as SSLibError
 from securesystemslib.interface import import_rsa_privatekey_from_file
-from securesystemslib.util import HASH_FUNCTION, get_file_details
-from tuf.exceptions import Error as TUFError
+from securesystemslib.util import get_file_details
+from tuf.exceptions import Error as TUFError, RepositoryError
 from tuf.repository_tool import (
     METADATA_DIRECTORY_NAME,
     TARGETS_DIRECTORY_NAME,
@@ -52,6 +52,7 @@ role_keys_cache = {}
 
 
 DISABLE_KEYS_CACHING = False
+HASH_FUNCTION = "sha256"
 
 
 def get_role_metadata_path(role):
@@ -141,8 +142,6 @@ def yubikey_signature_provider(name, key_id, key, data):  # pylint: disable=W061
     """
     from binascii import hexlify
 
-    data = securesystemslib.formats.encode_canonical(data).encode("utf-8")
-
     def _check_key_and_get_pin(expected_key_id):
         try:
             inserted_key = yk.get_piv_public_key_tuf()
@@ -237,8 +236,11 @@ class Repository:
         custom: custom target data
         """
         file_path = str(Path(file_path).absolute())
+        targets_directory_length = len(targets_obj._targets_directory) + 1
+        relative_path = file_path[targets_directory_length:].replace("\\", "/")
         normalize_file_line_endings(file_path)
-        targets_obj.add_target(file_path, custom)
+
+        targets_obj.add_target(relative_path, custom)
 
     def add_metadata_key(self, role, pub_key_pem, scheme=DEFAULT_RSA_SIGNATURE_SCHEME):
         """Add metadata key of the provided role.
@@ -440,7 +442,7 @@ class Repository:
             )
         )
 
-    def get_singed_targets_with_custom_data(self, roles):
+    def get_signed_targets_with_custom_data(self, roles):
         """Return all target files signed by the specified roles and and their custom data
         as specified in the metadata files
 
@@ -594,6 +596,50 @@ class Repository:
 
         return common_role.pop()
 
+    def check_roles_expiration_dates(
+        self, interval=None, start_date=None, excluded_roles=None
+    ):
+        """Determines which metadata roles have expired, or will expire within a time frame.
+        Args:
+        - interval(int): Number of days to look ahead for expiration.
+        - start_date(datetime): Start date to look for expiration.
+        - excluded_roles(list): List of roles to exclude from the search.
+
+        Returns:
+        - A dictionary of roles that have expired, or will expire within the given time frame.
+        Results are sorted by expiration date.
+        """
+        if start_date is None:
+            start_date = datetime.datetime.now()
+        if interval is None:
+            interval = 30
+        expiration_threshold = start_date + datetime.timedelta(days=interval)
+
+        if excluded_roles is None:
+            excluded_roles = []
+
+        target_roles = self.get_all_targets_roles()
+        main_roles = ["root", "targets", "snapshot", "timestamp"]
+        existing_roles = list(set(target_roles + main_roles) - set(excluded_roles))
+
+        expired_dict = {}
+        will_expire_dict = {}
+        for role in existing_roles:
+            expiry_date = self.get_expiration_date(role)
+            if start_date > expiry_date:
+                expired_dict[role] = expiry_date
+            elif expiration_threshold >= expiry_date:
+                will_expire_dict[role] = expiry_date
+        # sort by expiry date
+        expired_dict = {
+            k: v for k, v in sorted(expired_dict.items(), key=lambda item: item[1])
+        }
+        will_expire_dict = {
+            k: v for k, v in sorted(will_expire_dict.items(), key=lambda item: item[1])
+        }
+
+        return expired_dict, will_expire_dict
+
     def _collect_target_paths_of_role(self, target_roles_paths):
         all_target_relpaths = []
         for target_role_path in target_roles_paths:
@@ -806,7 +852,7 @@ class Repository:
         return [
             repo
             for repo in target_repositories
-            if all([fnmatch(repo, path) for path in role_paths])
+            if any([fnmatch(repo, path) for path in role_paths])
         ]
 
     def get_delegations_info(self, role_name):
@@ -912,7 +958,7 @@ class Repository:
         - securesystemslib.exceptions.FormatError: If 'PEM' is improperly formatted.
         - securesystemslib.exceptions.UnknownRoleError: If role does not exist
         """
-        securesystemslib.formats.ROLENAME_SCHEMA.check_match(role)
+        securesystemslib.formats.NAME_SCHEMA.check_match(role)
 
         if public_key is None:
             public_key = yk.get_piv_public_key_tuf()
